@@ -1,15 +1,16 @@
-use std::collections::BTreeMap;
-use std::time::Duration;
+use std::{collections::BTreeMap, time::Duration};
 
 use criterion::{criterion_group, criterion_main, BenchmarkId, Criterion};
 use indoc::indoc;
 use mit_commit::{CommitMessage, Trailer};
-
-use mit_commit_message_lints::external;
-use mit_commit_message_lints::mit::Author;
-use mit_commit_message_lints::mit::{get_commit_coauthor_configuration, set_commit_authors};
-use mit_commit_message_lints::relates::entities::RelateTo;
-use mit_commit_message_lints::relates::vcs::{get_relate_to_configuration, set_relates_to};
+use mit_commit_message_lints::{
+    external,
+    mit::{get_commit_coauthor_configuration, set_commit_authors, Author},
+    relates::{
+        entities::RelateTo,
+        vcs::{get_relate_to_configuration, set_relates_to},
+    },
+};
 
 const COMMIT_WITH_ALL_FEATURES: &str = indoc!(
     "
